BASE_URL = 'radoneyestationv2-api.azurewebsites.net/api'
SUPPORTED_INTERFACES = ['eth0', 'enp0s3', 'wlan0']
